{% extends "base.html" %}
{% load pages %}


{% block title %}{% title "Server Error" %}{% endblock %}


{% block header %}Server Error{% endblock %}


{% block breadcrumbs %}
    {% breadcrumbs extended=1 %}
    Server Error
{% endblock %}


{% block content_primary %}
    <p>We're sorry, but the site is currently experiencing some technical
    difficulties. </p>
    
    <h2>What you can try</h2>
    
    <ul>
        <li>Contact us, so we find out about the error as soon as possible.</li>
        <li>Come back in a few hours and try again.</li>
    </ul>
{% endblock %}