{% load pagination news %}
{% if article_list %}
    <ul class="news-article-list">
        {% for article in article_list %}
            <li>
                {% article_list_item article %}
            </li>
        {% endfor %}
    </ul>

    {% if page_obj %}
        {% pagination page_obj %}
    {% endif %}
{% else %}
    <p><em>There are no articles to display.</em>
{% endif %}
