{% extends "admin/base_site.html" %}


{% block extrastyle %}
    {{block.super}}
    <link rel="stylesheet" type="text/css" href="{{STATIC_URL}}admin/css/forms.css" />
{% endblock %}


{% block breadcrumbs %}{% endblock %}


{% block content %}
    <div id="content-main">

        {% if valid_link %}

            <p>Your admin username is <strong>{{user.username}}</strong>.
            Please enter your new account password in the form below.</p>

            <form method="post" action="">

                {% csrf_token %}

                <p>Password must be at least 8 characters and include 1 lower-case letter, 1 upper-case letter, 1 number and 1 special character (e.g. @, #, $)</p>


                {% for fieldset in adminform %}
                    {% include "admin/includes/fieldset.html" %}
                {% endfor %}

                <div class="submit-row">
                    <input type="submit" class="default" value="Create account"/>
                </div>

            </form>

        {% else %}

            <p>We're sorry, but this link has expired.</p>

            <p>Please ask your site administrator to send you a new invitation email.</p>

        {% endif %}

    </div>
{% endblock %}
